<template>
    <v-dialog v-model="show" :hide-overlay="hideOverlay" :persistent="persistent" width="300">
        <v-card :color="color" dark>
            <v-card-text>
                {{ text }}
                <v-progress-linear indeterminate color="white" class="mb-0"></v-progress-linear>
            </v-card-text>
        </v-card>
    </v-dialog>
</template>

<script>
import {mapState, mapActions} from "vuex";

export default {
    name: "ScreenLoader",
    data() {
        return {
            capacity: 30,
            maxDelay: 20000, // in ms
            timer: null,
        }
    },
    computed: {
        ...mapState({
            show: state => state.Loader.show,
            hideOverlay: state => state.Loader.hideOverlay,
            persistent: state => state.Loader.persistent,
            color: state => state.Loader.color,
            message: state => state.Loader.message,
            onMount: state => state.Loader.onMount
        }),
        text() {
            return this.message.substr(0, this.capacity)
                .concat(this.message.length > (this.capacity - 1) ? '...' : '');
        }
    },
    watch: {
        show(value) {
            if (value) {
                this.timer = setTimeout(() => {
                    this.showSnack([`Request took more than ${this.$options.filters.number_format(this.maxDelay)}ms.`, 'warning'])
                    this.hideLoader()
                }, this.maxDelay)
                if (typeof this.onMount === 'function') {
                    this.onMount()
                }
            } else {
                if (this.timer) {
                    clearTimeout(this.timer)
                }
            }
        }
    },
    methods: {
        ...mapActions("Loader", ["hideLoader"])
    }
}
</script>

<style scoped>

</style>
